@@ -169,7 +169,7 @@ class PostEndpoints:
             "Startdate": data["start_date"],
             "Enddate": data["end_date"],
             "Shorttext": data["organisational_unit_id"],
-            "Longtext": data["organisational_unit"],
+            "Longtext": data["organisational_unit"] if len(data['organisational_unit'])<=40 else data['organisational_unit'][:40], # SAP has a limit of 40 characters for longtext
             "OrgunitIDassigend": data["parent_organisational_unit_id"]
         }
         fields_to_update = {}
@@ -202,7 +202,7 @@ class PostEndpoints:
             "Startdate": data['start_date'],
             "Enddate": data['end_date'],
             "Shorttext": data['job_code'],
-            "Longtext": data['job'],
+            "Longtext": data['job'] if len(data['job'])<=40 else data['job'][:40], # SAP has a limit of 40 characters for longtext
             "Omleader": False if data['is_manager'] is None or data['is_manager'] == '' else data['is_manager'],
             "OrgunitIDassigend": data['sap_organisational_unit_id']
         }
@@ -280,6 +280,37 @@ class PostEndpoints:
         response = self.base_class.post_data(uri='ContractElementPost/*', data=base_body, return_key=None)
         return response
 
+    def post_additional_contract_element(self, data: dict, overload_fields: dict = None):
+        """
+        Post Contracts to SAP
+        :param data: Fields that are allowed are listed in allowed fields array. Update this whenever necessary
+        :param overload_fields: Give the guid and value from a free field if wanted
+        :return: status code for request and optional error message
+        """
+        allowed_fields = ['leading_level']
+        required_fields = ['afas_employee_id', 'sap_employee_id', 'start_date', 'end_date',
+                           'start_date_leading_level', 'end_date_leading_level']
+        self.__check_fields(data=data, required_fields=required_fields, allowed_fields=allowed_fields)
+
+        base_body = {
+            "Afasemployeenumber": data['afas_employee_id'],
+            "Employeenumber": "00000000" if data['sap_employee_id'] is None or data['sap_employee_id'] == '' else data['sap_employee_id'],
+            "Startdate": data['start_date'],
+            "Enddate": data['end_date'],
+            "LeadingLevelStartdate": data['start_date_leading_level'],
+            "LeadingLevelEnddate": data['end_date_leading_level']
+        }
+        # Add fields that you want to update a dict (adding to body itself is too much text)
+        fields_to_update = {}
+        fields_to_update.update({"LeadingLevel": data['leading_level']}) if 'leading_level' in data else fields_to_update
+        fields_to_update.update(overload_fields) if overload_fields is not None else ''
+
+        # Update the request body with update fields
+        base_body.update(fields_to_update)
+
+        response = self.base_class.post_data(uri='AdditionalContractElementPost/*', data=base_body, return_key=None)
+        return response
+
     def post_basic_pay(self, data: dict, overload_fields: dict = None):
         """
         Post Basic Pay data, like capacity level and monthly hours, to SAP
